import React, { useState, useRef, useEffect } from 'react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronDown, faChevronLeft, faCloudUploadAlt, faTimes, faFileExcel } from '@fortawesome/free-solid-svg-icons';
import { FileUploader } from 'react-drag-drop-files';
import Select from 'react-select'
import Swal from 'sweetalert2';
import { ServerDownAnimation } from '../../../../../assets/images';

const BASE_URL = process.env.REACT_APP_BASE_URL
const API_KEY = process.env.REACT_APP_API_KEY

const fileTypes = ['CSV', 'XLSX'];


const BulkMessage = ({ isSelectOpen, handleFocus, handleBlur, handleClick, onFileUpload }) => {
    const [applicationId, setApplicationId] = useState('');
    const [templateName, setTemplateName] = useState('');
    const [fileData, setFileData] = useState(null);
    const [selectedFileName, setSelectedFileName] = useState('');
    const [errors, setErrors] = useState({});
    const fileInputRef = useRef(null);
    const [applicationIds, setApplicationIds] = useState([]);
    const [isLoading, setIsLoading] = useState(false);
    const [isServer, setIsServer] = useState(true);
    const [errorMessage, setErrorMessage] = useState('');

    const [templateOptions, setTemplateOptions] = useState([]);
    const [templateId, setTemplateId] = useState('');
    const [selectedQuota, setSelectedQuota] = useState(0);

    useEffect(() => {
        const fetchData = () => {
            setIsLoading(true);

            fetch(`${BASE_URL}/application/list`, {
                method: 'GET',
                headers: {
                    'accept': 'application/json',
                    'x-api-key': API_KEY,
                },
            })
            .then(response => response.json())
            .then(appData => {
                if (appData.status_code === 200) {
                    setApplicationIds(appData.details.data);
                    return fetch(`${BASE_URL}/template/list?type=2`, {
                        method: 'GET',
                        headers: {
                            'accept': 'application/json',
                            'x-api-key': API_KEY,
                        },
                    });
                }
                setIsServer(false);
                setErrorMessage('Failed to fetch application IDs');
                throw new Error('Failed to fetch application IDs');
            })
            .then(response => response.json())
            .then(templateData => {
                if (templateData.status_code === 200) {
                    const templates = templateData.details.data.map(template => ({
                        value: template.id,
                        label: template.name,
                        desc: template.desc,
                    }));
                    setTemplateOptions(templates);
                    setIsServer(true);
                } else {
                    setIsServer(false);
                    setErrorMessage('Failed to fetch templates');
                    throw new Error('Failed to fetch templates');
                }
            })
            .catch(error => {
                console.error('Error:', error);
                setIsServer(false);
                setErrorMessage(error.message || 'Server connection failed');
            })
            .finally(() => {
                setIsLoading(false);
            });
        };

        fetchData();
    }, []);

    const handleApplicationChange = (e) => {
        const selectedId = e.target.value;
        const selectedApp = applicationIds.find(app => app.id === parseInt(selectedId));

        setApplicationId(selectedId);

        if (selectedApp) {
            setSelectedQuota(selectedApp.quota || 0);
        }
    };

    const handleTemplateChange = (selectedOption) => {
        setTemplateId(selectedOption.value);
        setTemplateName(selectedOption.label); // Set templateName here
    };

    const handleValidation = () => {
        const newErrors = {};
        if (!applicationId) newErrors.applicationId = "Application ID is required.";
        if (!templateName) newErrors.templateName = "Template Name is required.";
        if (!fileData) newErrors.fileData = "File is required.";
        
        setErrors(newErrors);
        return Object.keys(newErrors).length === 0;
    };

    const handleFileUpload = (file) => {
        if (file) {
            setFileData(file);
            setSelectedFileName(file.name);
            if (onFileUpload) {
                onFileUpload(file);
            }
        } else {
            setErrors((prevErrors) => ({
                ...prevErrors,
                fileData: "File upload failed."
            }));
        }
    };

    const handleButtonClick = () => {
        if (handleValidation()) {
            setIsLoading(true);
            const formData = new FormData();
            formData.append('application_id', applicationId);
            formData.append('template_id', templateId);
            formData.append('is_test', 'true');
            formData.append('mode_id', '9');
            formData.append('file', fileData);
    
            // Log the data being sent
            console.log('Form Data:', {
                application_id: applicationId,
                template_id: templateId,
                is_test: 'true',
                mode_id: '9',
                file: fileData,
            });
    
            fetch(`${BASE_URL}/wa/bulk-message`, {
                method: 'POST',
                headers: {
                    'x-api-key': API_KEY,
                    'accept': 'application/json',
                },
                body: formData,
            })
            .then(response => response.json())
            .then(data => {
                if (data.status_code === 200) {
                    Swal.fire({
                        icon: 'success',
                        title: 'Success!',
                        text: 'Bulk message sent successfully',
                    });
                } else {
                    Swal.fire({
                        icon: 'error',
                        title: 'Error!',
                        text: 'Failed to send bulk message',
                    });
                }
            })
            .catch(error => {
                console.error('Error:', error);
                Swal.fire({
                    icon: 'error',
                    title: 'Error!',
                    text: 'Failed to send bulk message',
                });
            })
            .finally(() => {
                setIsLoading(false);
            });
        } else {
            console.log('Validation errors:', errors);
        }
    };

    const handleFileCancel = () => {
        setFileData(null);
        setSelectedFileName('');
        if (fileInputRef.current) {
            fileInputRef.current.value = '';
        }
    };

    const downloadTemplate = async () => {
        if (templateId) {
            const url = `${BASE_URL}/template/download-excel/${templateId}`;
            try {
                const response = await fetch(url, {
                    method: 'GET',
                    headers: {
                        'x-api-key': API_KEY,
                    },
                });
                if (!response.ok) {
                    throw new Error('Failed to download template');
                }
                const blob = await response.blob();
                const downloadUrl = window.URL.createObjectURL(blob);
                const a = document.createElement('a');
                a.href = downloadUrl;
                a.download = `template_${templateName}.xlsx`;
                document.body.appendChild(a);
                a.click();
                a.remove();
            } catch (error) {
                Swal.fire({
                    icon: 'error',
                    title: 'Error',
                    text: `Failed to download template: ${error.message}`,
                });
            }
        } else {
            Swal.fire({
                icon: 'error',
                title: 'Error',
                text: 'Please select a template to download.',
            });
        }
    };

    // Server Down Component
    if (!isServer) {
        return (
            <div style={{ textAlign: 'center', marginTop: '50px' }}>
                <img
                    src={ServerDownAnimation}
                    alt="Server Down Animation"
                    style={{ width: '18rem', height: '18rem', marginBottom: '20px' }}
                />
                <h2 style={{ color: 'red' }}>Server tidak dapat diakses</h2>
                <p>{errorMessage || 'Silakan periksa koneksi internet Anda atau coba lagi nanti.'}</p>
                <button
                    onClick={() => window.location.reload()}
                    style={{
                        padding: '10px 20px',
                        backgroundColor: '#0542cc',
                        color: '#fff',
                        border: 'none',
                        borderRadius: '5px',
                        cursor: 'pointer'
                    }}>
                    Coba Lagi
                </button>
            </div>
        );
    }

    return (
        <div>
            {/* Inject keyframes for the spinner */}
            <style>
                {`
                @keyframes spin {
                    0% { transform: rotate(0deg); }
                    100% { transform: rotate(360deg); }
                }
                `}
            </style>

            {isLoading && (
                <div style={styles.loadingOverlay}>
                    <div style={styles.spinner}></div>
                </div>
            )}

            <div className="form-group row align-items-center">
                <div className="col-md-6">
                    <div style={styles.selectWrapper}>
                        <select
                            id="applicationId"
                            className="form-control"
                            style={styles.select}
                            value={applicationId}
                            onChange={handleApplicationChange}
                            onFocus={handleFocus}
                            onBlur={handleBlur}
                        >
                            <option value="">Select Application ID</option>
                            {applicationIds.map((app) => (
                                <option key={app.id} value={app.id}>
                                    {app.name}
                                </option>
                            ))}
                        </select>
                        <FontAwesomeIcon
                            icon={isSelectOpen ? faChevronDown : faChevronLeft}
                            style={styles.chevronIcon}
                        />
                    </div>
                    {errors.applicationId && <small style={{ color: 'red' }}>{errors.applicationId}</small>}
                </div>
                <div className="col-md-6">
                    <p className="text-secondary" style={{ fontSize: '16px', fontWeight: '400', margin: '0', marginTop: '8px' }}>
                        Remaining Quota
                    </p>
                    <div style={styles.remainingQuota}>
                        {console.log(selectedQuota)}
                        <span style={styles.quotaText}>{selectedQuota}</span>
                        <span style={styles.timesText}>(times)</span>
                    </div>
                </div>
            </div>

            <div className="form-group row align-items-center mt-4">
                <div className="col-md-6">
                    <Select
                        id="templateId"
                        value={templateOptions.find(option => option.value === templateId)}
                        onChange={handleTemplateChange}
                        options={templateOptions}
                        placeholder="Select Template"
                        isSearchable
                        menuPortalTarget={document.body}
                        menuPlacement="auto"
                    />
                    {errors.templateName && <small style={{ color: 'red' }}>{errors.templateName}</small>}
                </div>
            </div>

            {/* Upload Section */}
            <div className='col-md-6'>
                <div className="row form-group mt-4">
                    <div style={{ display: 'flex', alignItems: 'center' }}>
                        <label htmlFor="uploadFile" style={styles.customLabel}>
                            Upload File (CSV or Excel)
                        </label>
                        <button onClick={downloadTemplate} className="btn btn-link">Download Template</button>
                    </div>
                    <FileUploader
                        handleChange={handleFileUpload}
                        name="file"
                        types={fileTypes}
                        multiple={false}
                        onDrop={(files) => {
                            // Ensure files array is not empty
                            if (files.length > 0) {
                                handleFileUpload(files[0]);
                            }
                        }}
                        // Modify the FileUploader children prop to prevent double file dialog
                        children={
                            <div style={styles.uploadArea}>
                                <FontAwesomeIcon icon={faCloudUploadAlt} style={styles.uploadIcon} />
                                <p style={styles.uploadText}>Drag and Drop Here</p>
                                <p>Or</p>
                                {/* Remove the onClick handler here since it's causing the double trigger */}
                                <span style={{ color: '#0542CC', cursor: 'pointer' }}>Browse</span>
                                <p className="text-muted">Supported file types: CSV, XLSX</p>
                            </div>
                        }

                    />
                    <input
                        type="file"
                        id="fileUpload"
                        ref={fileInputRef}
                        style={{ display: 'none' }}
                        accept=".csv, .xlsx"
                        onChange={e => {
                            if (e.target.files.length > 0) {
                                handleFileUpload(e.target.files[0]);
                            }
                        }}
                    />
                    {errors.fileData && <small style={{ color: 'red' }}>{errors.fileData}</small>}
                </div>
            </div>

            {/* Display uploaded file name */}
            {selectedFileName && (
                <div className="col-md-6 mt-4">
                    <div style={styles.fileWrapper}>
                        <FontAwesomeIcon icon={faFileExcel} style={styles.imageIcon} />
                        <div style={styles.fileDetails}>
                            <h5 style={styles.uploadedFileTitle}>Uploaded File:</h5>
                            <p style={styles.uploadedFileName}>{selectedFileName}</p>
                        </div>
                        <button
                            style={styles.closeButton}
                            onClick={handleFileCancel}
                            aria-label="Remove uploaded file"
                        >
                            <FontAwesomeIcon
                                icon={faTimes}
                                style={styles.closeIcon}
                            />
                        </button>
                    </div>
                </div>
            )}

            <div style={styles.selectWrapper}>
                <div style={styles.submitButton}>
                    <button onClick={handleButtonClick} className="btn d-flex justify-content-center align-items-center me-2" style={{ backgroundColor: '#0542CC' }}>
                        <p className="text-white mb-0">Make SMS Demo</p>
                    </button>
                </div>
            </div>
        </div>
    );
};

export default BulkMessage;

const styles = {
    loadingOverlay: {
        position: 'fixed',
        top: 0,
        left: 0,
        width: '100%',
        height: '100%',
        backgroundColor: 'rgba(0, 0, 0, 0.5)',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        zIndex: 9999
    },
    spinner: {
        width: '50px',
        height: '50px',
        border: '5px solid #f3f3f3',
        borderTop: '5px solid #0542CC',
        borderRadius: '50%',
        animation: 'spin 1s linear infinite'
    },
    selectWrapper: {
        position: 'relative',
        marginTop: '0',
    },
    select: {
        width: '100%',
        paddingRight: '30px',
        flex: 1,
        fontSize: '16px',
        outline: 'none',
    },
    chevronIcon: {
        position: 'absolute',
        right: '10px',
        top: '50%',
        transform: 'translateY(-50%)',
        pointerEvents: 'none',
    },
    remainingQuota: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        marginTop: '4px',
    },
    quotaText: {
        fontSize: '40px',
        color: '#0542cc',
        fontWeight: '600',
    },
    timesText: {
        marginLeft: '8px',
        verticalAlign: 'super',
        fontSize: '20px',
    },
    submitButton: {
        marginLeft: 'auto',
        marginTop: '1rem',
        textAlign: 'start',
        position: 'relative',
        zIndex: 1,
    },
    uploadArea: {
        backgroundColor: '#e6f2ff',
        height: '250px',
        cursor: 'pointer',
        paddingTop: '22px',
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'center',
        alignItems: 'center',
        border: '1px solid #ced4da',
        borderRadius: '0.25rem',
    },
    uploadIcon: {
        fontSize: '40px',
        color: '#0542cc',
        marginBottom: '7px',
    },
    uploadText: {
        color: '#1f2d3d',
        fontWeight: '400',
        fontSize: '16px',
        lineHeight: '13px',
    },
    uploadError: {
        color: 'red',
    },
    fileWrapper: {
        backgroundColor: '#fff',
        border: '0.2px solid gray',
        padding: '15px',
        borderRadius: '5px',
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'space-between',
        height: 'auto',
        flexWrap: 'wrap',
    },
    imageIcon: {
        color: '#0542cc',
        fontSize: '24px',
        marginBottom: '1rem',
    },
    fileDetails: {
        flex: 1,
        marginLeft: '1rem',
        marginRight: '1rem',
        marginTop: '0.2rem',
        minWidth: '0', // Ensures the text doesn't overflow
    },
    uploadedFileTitle: {
        fontSize: '1rem',
        margin: '0',
        wordWrap: 'break-word', // Ensures the text wraps within the container
    },
    uploadedFileName: {
        fontSize: '0.875rem',
        margin: '0',
        wordWrap: 'break-word', // Ensures the text wraps within the container
    },
    closeButton: {
        background: 'none',
        border: 'none',
        cursor: 'pointer',
    },
    closeIcon: {
        color: 'red',
        fontSize: '26px',
    },
    customLabel: {
        fontWeight: 600,
        fontSize: '14px',
        color: '#212529'
    },
    submitButton: {
        marginTop: '20px',
    },
};