import React, { useState, useEffect } from 'react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronDown, faChevronLeft } from '@fortawesome/free-solid-svg-icons';
import Select from 'react-select'
import Swal from 'sweetalert2';
import { ServerDownAnimation } from '../../../../../assets/images';

const BASE_URL = process.env.REACT_APP_BASE_URL
const API_KEY = process.env.REACT_APP_API_KEY

const SingleMessage = ({ isSelectOpen, handleFocus, handleBlur }) => {
    const [applicationId, setApplicationId] = useState('');
    const [phoneId, setPhoneId] = useState('');
    const [preview, setPreview] = useState(null);
    const [errors, setErrors] = useState({});
    const [applicationIds, setApplicationIds] = useState([]);  
    const [selectedQuota, setSelectedQuota] = useState(0);
    const [isLoading, setIsLoading] = useState(false);
    const [isServer, setIsServer] = useState(true);
    const [errorMessage, setErrorMessage] = useState('');

    const [templateOptions, setTemplateOptions] = useState([]);
    const [templateId, setTemplateId] = useState('');
    const [variables, setVariables] = useState([]);
    const [desc, setDesc] = useState('');

    useEffect(() => {
        const fetchData = () => {
            setIsLoading(true);
    
            fetch(`${BASE_URL}/application/list`, {
                method: 'GET',
                headers: {
                    'accept': 'application/json',
                    'x-api-key': API_KEY,
                },
            })
            .then(response => response.json())
            .then(appData => {
                if (appData.status_code === 200) {
                    setApplicationIds(appData.details.data);
                    return fetch(`${BASE_URL}/template/list?type=2`, {
                        method: 'GET',
                        headers: {
                            'accept': 'application/json',
                            'x-api-key': API_KEY,
                        },
                    });
                }
                setIsServer(false);
                setErrorMessage('Failed to fetch application IDs');
                throw new Error('Failed to fetch application IDs');
            })
            .then(response => response.json())
            .then(templateData => {
                if (templateData.status_code === 200) {
                    const templates = templateData.details.data.map(template => ({
                        value: template.id,
                        label: template.name,
                        desc: template.desc,
                    }));
                    setTemplateOptions(templates);
                    setIsServer(true);
                } else {
                    setIsServer(false);
                    setErrorMessage('Failed to fetch templates');
                    throw new Error('Failed to fetch templates');
                }
            })
            .catch(error => {
                console.error('Error:', error);
                setIsServer(false);
                setErrorMessage(error.message || 'Server connection failed');
            })
            .finally(() => {
                setIsLoading(false);
            });
        };
    
        fetchData();
    }, []);

    const handleApplicationChange = (e) => {
        const selectedId = e.target.value;
        const selectedApp = applicationIds.find(app => app.id === parseInt(selectedId));
    
        setApplicationId(selectedId);
    
        if (selectedApp) {
            setSelectedQuota(selectedApp.quota || 0);
        }
    };
    

    const handleTemplateChange = (selectedOption) => {
        setTemplateId(selectedOption.value);
        const selectedTemplate = templateOptions.find(template => template.value === selectedOption.value);
        const placeholders = selectedTemplate ? selectedTemplate.desc.match(/\{([^}]+)\}/g) || [] : [];
        setVariables(Array(placeholders.length).fill(''));
        setDesc(selectedTemplate ? selectedTemplate.desc : '');
    };

    
    const handleValidation = () => {
        const errors = {};
        if (!applicationId) errors.applicationId = 'Application ID is required.';
        if (!phoneId) errors.phoneId = 'Phone number is required.';
        if (!templateId) errors.templateId = 'Template selection is required.';
        if (variables.some(variable => variable.trim() === '')) errors.variables = 'All variables must be filled.';
        setErrors(errors);
        return Object.keys(errors).length === 0;
    };

    const handleButtonClick = () => {
        if (handleValidation()) {
            // Start loading
            setIsLoading(true);
    
            fetch(`${BASE_URL}/wa/message`, {
                method: 'POST',
                headers: {
                    accept: 'application/json',
                    'Content-Type': 'application/json',
                    'x-api-key': API_KEY,
                },
                body: JSON.stringify({
                    application_id: parseInt(applicationId),
                    phone: phoneId,
                    template_id: parseInt(templateId),
                    is_test: true,
                    mode_id: 9,
                    vars: variables,
                }),
            })
            .then(response => response.json())
            .then(data => {
                if (data.status_code === 201 || data.status_code === 200) {
                    // Decrease the quota
                    setSelectedQuota(prevQuota => prevQuota - 1);
                    
                    // Set preview data
                    setPreview({
                        message: `Message sent successfully!`,
                        details: `Session ID: ${data.details.data.session_id}\nCreated at: ${new Date(
                            data.details.data.created_at
                        ).toLocaleString()}`,
                    });
    
                    // Show success alert
                    Swal.fire({
                        icon: 'success',
                        title: 'Success!',
                        text: 'Message sent successfully',
                    });
                } else {                    
                    // Show error alert
                    Swal.fire({
                        icon: 'error',
                        title: 'Error!',
                        text: 'Failed to send message',
                        showConfirmButton: true
                    });
                    // Set error message
                    setErrors({ ...errors, api: 'Failed to send message' });
                }
            })
            .catch(error => {
                console.error('Error:', error);
                setErrors({ ...errors, api: 'Failed to send message' });                
                // Show error alert
                Swal.fire({
                    icon: 'error',
                    title: 'Error!',
                    text: 'Failed to send message',
                    showConfirmButton: true
                });
            })
            .finally(() => {
                // Stop loading
                setIsLoading(false);
            });
        }
    };      

    // Server Down Component
    if (!isServer) {
        return (
            <div style={{ textAlign: 'center', marginTop: '50px' }}>
                <img
                    src={ServerDownAnimation}
                    alt="Server Down Animation"
                    style={{ width: '18rem', height: '18rem', marginBottom: '20px' }}
                />
                <h2 style={{ color: 'red' }}>Server tidak dapat diakses</h2>
                <p>{errorMessage || 'Silakan periksa koneksi internet Anda atau coba lagi nanti.'}</p>
                <button
                    onClick={() => window.location.reload()}
                    style={{
                        padding: '10px 20px',
                        backgroundColor: '#0542cc',
                        color: '#fff',
                        border: 'none',
                        borderRadius: '5px',
                        cursor: 'pointer'
                    }}>
                    Coba Lagi
                </button>
            </div>
        );
    }

    return (
        <div>
            {/* Inject keyframes for the spinner */}
            <style>
                {`
                @keyframes spin {
                    0% { transform: rotate(0deg); }
                    100% { transform: rotate(360deg); }
                }
                `}
            </style>

            {isLoading && (
                <div style={styles.loadingOverlay}>
                    <div style={styles.spinner}></div>
                </div>
            )}
            <div className="form-group row align-items-center">
                <div className="col-md-6">
                    <div style={styles.selectWrapper}>
                        <select
                            id="applicationId"
                            className="form-control"
                            style={styles.select}
                            value={applicationId}
                            onChange={handleApplicationChange}
                            onFocus={handleFocus}
                            onBlur={handleBlur}
                        >
                            <option value="">Select Application ID</option>
                            {applicationIds.map((app) => (
                                <option key={app.id} value={app.id}>
                                    {app.name}
                                </option>
                            ))}
                        </select>
                        <FontAwesomeIcon
                            icon={isSelectOpen ? faChevronDown : faChevronLeft}
                            style={styles.chevronIcon}
                        />
                    </div>
                    {errors.applicationId && <p className="text-danger">{errors.applicationId}</p>}
                </div>
                <div className="col-md-6">
                    <p className="text-secondary" style={{ fontSize: '16px', fontWeight: '400', margin: '0', marginTop: '8px' }}>
                        Remaining Quota
                    </p>
                    <div style={styles.remainingQuota}>
                        {console.log(selectedQuota)}
                        <span style={styles.quotaText}>{selectedQuota}</span>
                        <span style={styles.timesText}>(times)</span>
                    </div>
                </div>
            </div>

            <div className="form-group row align-items-center mt-4">
                <div className="col-md-6">
                    <div className="input-group">
                        <span className="input-group-prepend">
                            <span className="input-group-text">Phone Number</span>
                        </span>
                        <input
                            type="text"
                            id="phoneId"
                            className="form-control"
                            placeholder="Phone Number"
                            value={phoneId}
                            onChange={(e) => {
                                const value = e.target.value;
                                // Allow only digits and enforce length constraints
                                if (/^\d*$/.test(value) && value.length <= 14) {
                                    setPhoneId(value);
                                }
                            }}
                            minLength={9}
                            maxLength={14}
                        />
                    </div>
                    {errors.phoneId && <p className="text-danger">{errors.phoneId}</p>}
                </div>

                <div className="col-md-6">
                    <Select
                        id="templateId"
                        value={templateOptions.find(option => option.value === templateId)}
                        onChange={handleTemplateChange}
                        options={templateOptions}
                        placeholder="Select Template"
                        isSearchable
                        menuPortalTarget={document.body}
                        menuPlacement="auto"
                    />
                    {errors.templateId && <p className="text-danger">{errors.templateId}</p>}

                    {/* Description Preview */}
                    {desc && (
                        <div className="alert alert-info">
                            <strong>Selected Template Description:</strong> {desc}
                        </div>
                    )}
                </div>
            </div>

            {/* Dynamic Variable Inputs */}
            <div className="form-group row mt-4">
                {variables.map((_, index) => (
                    <div className="col-md-6 mb-3" key={index}>
                        <div className="input-group">
                            <input
                                type="text"
                                className="form-control"
                                placeholder={`Variable ${index + 1}`}
                                value={variables[index]}
                                onChange={(e) => {
                                    const newVars = [...variables];
                                    newVars[index] = e.target.value;
                                    setVariables(newVars);
                                }}
                            />
                        </div>
                    </div>
                ))}
            </div>



            <div style={styles.submitButton}>
                <button onClick={handleButtonClick} className="btn d-flex justify-content-center align-items-center me-2" style={{ backgroundColor: '#0542CC' }}>
                    <p className="text-white mb-0">Make SMS Demo</p>
                </button>
            </div>

            {/* Preview Section */}
            {preview && (
                <div style={styles.preview}>
                    <div style={styles.waMessagePreview}>
                        <p><strong>[Sips & Synergy Executive]</strong></p>
                        <p>{preview.message}</p>
                        <p>{preview.details}</p>
                        <button className="btn btn-primary mt-3">Maps Event Location</button>
                    </div>
                </div>
            )}
        </div>
    );
};

export default SingleMessage;

const styles = {
    loadingOverlay: {
        position: 'fixed',
        top: 0,
        left: 0,
        width: '100%',
        height: '100%',
        backgroundColor: 'rgba(0, 0, 0, 0.5)',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        zIndex: 9999
    },
    spinner: {
        width: '50px',
        height: '50px',
        border: '5px solid #f3f3f3',
        borderTop: '5px solid #0542CC',
        borderRadius: '50%',
        animation: 'spin 1s linear infinite'
    },
    selectWrapper: {
        position: 'relative',
        marginTop: '0',
    },
    select: {
        width: '100%',
        paddingRight: '30px',
        flex: 1,
        fontSize: '16px',
        outline: 'none',
    },
    chevronIcon: {
        position: 'absolute',
        right: '10px',
        top: '50%',
        transform: 'translateY(-50%)',
        pointerEvents: 'none',
    },
    remainingQuota: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        marginTop: '4px',
    },
    quotaText: {
        fontSize: '40px',
        color: '#0542cc',
        fontWeight: '600',
    },
    timesText: {
        marginLeft: '8px',
        verticalAlign: 'super',
        fontSize: '20px',
    },
    submitButton: {
        marginLeft: 'auto',
        marginTop: '1rem',
        textAlign: 'start',
        position: 'relative',
        zIndex: 1,
    },
    waMessagePreview: {
        backgroundColor: '#F8F9FA',
        padding: '15px',
        borderRadius: '8px',
        border: '1px solid #dcdcdc',
        marginBottom: '20px',
    },
    preview: {
        marginTop: '20px',
    },
};
